BraidzSummary

Struct BraidzSummary 

pub struct BraidzSummary {
    pub filename: String,
    pub filesize: u64,
    pub metadata: BraidMetadata,
    pub cam_info: CamInfo,
    pub expected_fps: f64,
    pub calibration_info: Option<CalibrationSummary>,
    pub data2d_summary: Option<Data2dSummary>,
    pub kalman_estimates_summary: Option<KalmanEstimatesSummary>,
    pub reconstruct_latency_usec_summary: Option<HistogramSummary>,
    pub reprojection_distance_100x_pixels_summary: Option<HistogramSummary>,
}
A summary of a braidz file (or braid directory).

Even for a many-gigabyte braidz file, this is expected to allocate megabytes, but not gigabytes, of memory and will contain a summary of the data such as filename, calibration, images, reconstruction quality metrics, and so on. It will not load the entire braidz file to memory.

Fields

filename: String

The filename of the braidz file or braid directory.

filesize: u64

Number of bytes in a braidz file. (This is meaningless for braid directories.)

metadata: BraidMetadatacam_info: CamInfoexpected_fps: f64calibration_info: Option<CalibrationSummary>data2d_summary: Option<Data2dSummary>kalman_estimates_summary: Option<KalmanEstimatesSummary>reconstruct_latency_usec_summary: Option<HistogramSummary>reprojection_distance_100x_pixels_summary: Option<HistogramSummary>